@@ -30,6 +30,15 @@ class AWSECSHandler:
             **kwargs,
         }
 
+        if settings.AWS_CLUSTER_LAUNCH == 'FARGATE':
+            run_kwargs['networkConfiguration'] = {
+                'awsvpcConfiguration': {
+                    'subnets': settings.AWS_EC2_SUBNETS,
+                    'securityGroups': settings.AWS_EC2_SECURITY_GROUPS,
+                    'assignPublicIp': 'DISABLED'
+                }
+            }
+
         if command:
             command = command.split() if isinstance(command, str) else command
             run_kwargs['overrides'] = {
