@@ -1,4 +1,3 @@
-import json
 from django.conf import settings
 
 import boto3
@@ -18,14 +17,13 @@ class AWSSQSHandler:
         )
 
     def send_message(self, **kwargs):
-        attributes = kwargs.get('messageAttributes')
+        attributes = kwargs.get('MessageAttributes')
         if attributes:
-            kwargs.update({
-                "messageAttributes": self._sqs_attributes_cleaner(attributes)})
+            self._sqs_attributes_cleaner(attributes)
 
         return self.client.send_message(**kwargs)
 
-    def _sqs_attributes_cleaner(attributes):
+    def _sqs_attributes_cleaner(self, attributes):
         """Transform SQS attributes from Lambda event to SQS message."""
         d = dict.fromkeys(attributes)
         for k in d:
